{% block content %}{% endblock %}
<br>
--<br>
{% if app.config.get('EMAIL_INBOUND_DOMAIN') %}
{{ _('Reply to this email directly or') }}
{% endif %}
<a href="{{ url_for('project', project_id=card.project.slug, _external=True) }}#{{ card.ref }}">{{ _('view it in Kantree') }}</a>
{% if user %}
<p><small>(<a href="{{ url_for('unsubscribe_notifications', token=user.create_user_token(), _external=True) }}">{{ _('Unsubscribe from email notifications') }}</a>)</small></p>
{% endif %}
