---
subject: "L'importation de votre projet sur Kantree est terminée"
---
{% use_layout %}

<{mail_image_block url_for_static('assets/project.png', _external=True) width="200" }/>

<{mail_block center=True}>
  {% if success %}
  Votre projet <strong>{{title}}</strong> a été importé avec succès!
  {% else %}
  Malheureusement, une erreur est survenue pendant l'importation de votre projet <strong>{{title}}</strong>.
  {% endif %}
</{}>

<{mail_action_block label="Voir le projet" url=url_for('project', project_id=id, _external=True) }/>
