<p>A message was left on your request:</p>

{{activity.obj.message|markdown|safe}}

{% if request.form.request_page %}
<hr>
<p>You can view your request at <a href="{{ url_for('request', request_token=request.token, _external=True) }}">{{ url_for('request', request_token=request.token, _external=True) }}</a></p>
{% endif %}
