---
subject: "{{invite_from}} vous a invité à rejoindre {{title}} sur Kantree"
---
{% use_layout %}

<{mail_image_block url_for_static('assets/project.png', _external=True) width="200" }/>

<{mail_block center=True}>
  <p>Vous avez été invité à rejoindre le projet <strong>{{ title }}</strong> sur Kantree.</p>
  {% if message %}
  <p>{{message}}</p>
  {% endif %}
</{}>

<{mail_action_block label="Rejoindre maintenant" url=app.config.get('SIGNUP_URL') or url_for('users.signup', invite=1, email=invite_email, locale="fr", _external=True) }/>

<{mail_block center=True}><small>(Vous devrez créer un compte avec cette adresse email.)</small></{}>

