---
subject: Your project has finished importing in Kantree
---
{% use_layout %}

<{mail_image_block url_for_static('assets/project.png', _external=True) width="200" }/>

<{mail_block center=True}>
  {% if success %}
  Your project <strong>{{title}}</strong> has been successfuly imported!
  {% else %}
  Unfortunately, an error occured while importing your project <strong>{{title}}</strong>.
  {% endif %}
</{}>

<{mail_action_block label="Visit your project" url=url_for('project', project_id=id, _external=True) }/>
