---
subject: Suivez le lien pour ré-initialiser votre mot de passe
---
{% use_layout %}

<{ mail_block center=True }>
  Vous avez demandé une ré-initialisation de votre mot de passe. Veuillez suivre ce lien pour procéder:
</{}>
<{ mail_action_block label="Ré-initialiser votre mot de passe" url=url_for("users.reset_password", token=token, _external=True) }/>
