{% use_layout %}

<{mail_image_block url_for_static('assets/project.png', _external=True) width="200" }/>

<{mail_block}>
  {% block billing_content %}{{ content|safe }}{% endblock %}
</{}>

<{mail_action_block label="Manage billing" url=url_for('org', slug=org.slug, _external=True) + '#billing' }/>

<{mail_block}>
  <p>
    {{_('If you have any question, feel free to reply to this email.')}}
  </p>
  <p>
    {{_("Cheers,<br>The Kantree team")|safe}}
  </p>
  <p>
    <small>{{_("ps: You are receiving this email because your are an owner of this team")}}</small>
  </p>
</{}>
