{% use_layout "layouts/base.html" %}

<{mail_block}>
  {{ text_body|clickable_links|nl2br }}
</{}>

{% block footer %}
  <p>
    {{_('You are receiving this email because you have submitted a request to %s') % org_name}}
  </p>
{% endblock %}
