{% use_layout %}

<{mail_block}>
  {{ text_body|clickable_links|nl2br }}
</{}>

{% block footer %}
  {{ super() }}
  {% if user is defined and user %}
  <p>
    <a href="{{ url_for('account', _external=True) }}">{{_('Update your email settings')}}</a> or
    <a href="{{ url_for('unsubscribe_notifications', token=user.create_user_token(), _external=True) }}">{{_('Unsubscribe to email notifications')}}</a>
  </p>
  {% endif %}
{% endblock %}
