---
subject: "{{invite_from}} has invited you to join the project {{title}} in Kantree"
---
{% use_layout %}

<{mail_image_block url_for_static('assets/project.png', _external=True) width="200" }/>

<{mail_block center=True}>
  <p>You have been invited to join the project <strong>{{ title }}</strong> in Kantree.</p>
  {% if message %}
  <p>{{message}}</p>
  {% endif %}
</{}>

<{mail_action_block label="Join now" url=app.config.get('SIGNUP_URL') or url_for('users.signup', invite=1, email=invite_email, _external=True) }/>

<{mail_block center=True}><small>(You will need to signup using this email address.)</small></{}>

<{mail_block}>
  <p>Kantree is an easy to use collaboration &amp; work management platform where your team can organize, plan and manage its work.</p>
</{}>
