<p>Un message a été publié sur votre demande:</p>

{{activity.obj.message|markdown|safe}}

{% if request.form.request_page %}
<hr>
<p>Visualiser votre demande sur <a href="{{ url_for('request', request_token=request.token, _external=True) }}">{{ url_for('request', request_token=request.token, _external=True) }}</a></p>
{% endif %}
