---
subject: "Your Kantree invoice for {{invoice.customer.name}} is available"
---
{% extends "layouts/invoice.html" %}

{% block invoice_header %}
  <img src="https://kantree.io/static/logo-black.png" style="display: block; margin-bottom: 20px">
  You will find below your monthly Kantree invoice for the team
  <strong>{{invoice.customer.name}}</strong>.
  <br><br>
  {{invoice.issued_at.strftime('%d/%m/%y')}}<br>
  #{{invoice.ref}}<br><br>
  {{invoice.name}}<br>
  {{invoice.address_line1}}<br>
  {% if invoice.address_line2 %}{{invoice.address_line2}}<br>{% endif %}
  {{invoice.city}}<br>
  {{invoice.zipcode}}<br>
  {% if invoice.state %}{{invoice.state}}<br>{% endif %}
  {% if invoice.is_eu_country and invoice.eu_vat_number %}
  <br><br>Your VAT number: {{invoice.eu_vat_number}}
  {% endif %}
{% endblock %}

{% block invoice_footer %}
<p>
  If you have any questions regarding this invoice or your payment, contact us at
  <a href="mailto:contact@kantree.io">contact@kantree.io</a> (or reply to this email).
</p>
<p>
  Thank you for using Kantree!
</p>
<p style="font-size: 11px; color: #888">
  Kantree is made by <a href="http://digicoop.io">Digicoop</a>:<br>
  Digicoop (RCS 812479806 PARIS)<br>
  SCOP ARL à capital variable de 3500€<br>
  10 rue Lechapelais, 75017 Paris, France<br>
  VAT: FR53812479806<br>
</p>
{% endblock %}
