---
subject: Vous avez rejoint une équipe sur Kantree
---
{% use_layout %}

<{mail_image_block url_for_static('assets/project.png', _external=True) width="200" }/>

<{mail_block center=True}>
  <p>Vous avez été ajouté comme membre à l'équipe <strong>{{ orgname }}</strong> sur Kantree.</p>
  {% if message %}
  <p>{{message}}</p>
  {% endif %}
</{}>

<{mail_action_block label="Voir l'équipe maintenant" url=url_for('org', slug=slug, _external=True) }/>


