{% extends "layouts/base.html" %}

{% block main %}
  <img src="{{ url_for('static', filename='navbar-logo-black.png', _external=True) }}" alt="Kantree"
    style="margin: 0 0 10px 0; display: block">
  {{ super() }}
{% endblock %}

{% block footer %}
  <p>
    {{_('You are receiving this email because you are signed up to Kantree')}}
  </p>
{% endblock %}
