---
subject: Validate your email
---
{% use_layout %}

<{mail_image_block url_for_static('assets/project.png', _external=True) width="200" }/>

<{mail_block center=True}>
  <p>Click on the link below to confirm your email and start using Kantree</p>
</{}>

<{ mail_action_block label="Validate your email" url=url_for("users.validate_email", token=token, _external=True) }/>
