"""kantree_special_user_avatar_url

Revision: 0177
Revision ID: 23727a96713b
Revises: 4fc19fa2e6da
Create Date: 2020-03-04 15:15:45.789846

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '23727a96713b'
down_revision = '4fc19fa2e6da'
branch_labels = None
depends_on = None


def upgrade():
    op.execute("""
        UPDATE users SET avatar_filename = replace(avatar_filename, '/static/img/favicon.png', '/static/favicon.png') WHERE username = 'Kantree' AND is_special_user
    """)


def downgrade():
    pass
