{% extends "users/layout.html" %}
{% block users_content %}
<form action="" method="post" id="reset-password-form" class="login-form">
  {{ form.hidden_tag() }}
  <h2>{{ _("Reset password") }}</h2>
  <div class="form-group">
    <label for="password" class="form-label">{{form.password.label.text}}</label>
    {{ form.password(class_="form-control form-control-lg") }}
  </div>
  <div class="form-group">
    <label for="confirm_password" class="form-label">{{form.confirm_password.label.text}}</label>
    {{ form.confirm_password(class_="form-control form-control-lg") }}
  </div>
  <button type="submit" class="btn btn-primary btn-lg">{{_("Reset password")}}</button>
</form>
{% endblock %}
