{% extends "users/layout.html" %}
{% block users_content %}
  <form action="" method="post" class="login-form" id="login-form">
    {{ form.hidden_tag() }}
    <div class="form-group">
      <label for="code" class="form-label">{{form.code.label.text}}</label>
      {{form.code(class_="form-control form-control-lg", autocomplete="off", autofocus="autofocus")}}
    </div>
    <div class="form-group">
      <label>{{ form.remember() }} {{form.remember.label.text}}</label>
    </div>
    <button type="submit" class="btn btn-primary btn-lg">{{_("Login")}}</button>
  </form>
{% endblock %}
