"""models_cache_id

Revision: 0018
Revision ID: 355b90f95fc4
Revises: 26dc21c88e6
Create Date: 2015-08-17 14:45:44.630343

"""

# revision identifiers, used by Alembic.
revision = '355b90f95fc4'
down_revision = '26dc21c88e6'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('card_models', sa.Column('cache_id', sa.String(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('card_models', 'cache_id')
    ### end Alembic commands ###
