"""project_guide

Revision: 0098
Revision ID: 3a512b4f3d8f
Revises: 4e63e5c80ada
Create Date: 2017-06-20 18:17:57.849503

"""

# revision identifiers, used by Alembic.
revision = '3a512b4f3d8f'
down_revision = '4e63e5c80ada'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.add_column('projects', sa.Column('guide', sa.Text(), nullable=True))


def downgrade():
    op.drop_column('projects', 'guide')
