"""invoice_eu_vat_amount

Revision: 0028
Revision ID: 43ed95babe0a
Revises: 13c9e3e73486
Create Date: 2015-09-22 20:03:26.698797

"""

# revision identifiers, used by Alembic.
revision = '43ed95babe0a'
down_revision = '13c9e3e73486'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

def upgrade():
    op.add_column('invoices', sa.Column('eu_vat_amount', sa.Float(), nullable=True))


def downgrade():
    op.drop_column('invoices', 'eu_vat_amount')
