"""migrate_view_modes

Revision: 0218
Revision ID: 681ff6dac033
Revises: bac8354bc42a
Create Date: 2021-10-22 16:20:31.251297

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '681ff6dac033'
down_revision = 'bac8354bc42a'
branch_labels = None
depends_on = None


def upgrade():
    op.execute("UPDATE views SET mode = 'report' WHERE mode = 'analytics'")


def downgrade():
    pass
