{% if THIRD_PARTY_ACCOUNT_PROVIDERS|length > 0 %}
<div id="auth-third-party-accounts">
  {% for provider in THIRD_PARTY_ACCOUNT_PROVIDERS %}
    {% if provider.login_view %}
      <a href="{{ url_for(provider.login_view) }}" class="{{ '' if provider.login_btn_img else 'btn btn-default' }}" onclick="ga('send', 'event', 'account', 'login', '{{provider.name}}')">
        {% if provider.login_btn_img %}
          <img src="{{ provider.login_btn_img }} " alt="{{ provider.login_label }}">
        {% else %}
          {% if provider.icon %}<i class="fa fa-{{ provider.icon }}"></i> {% endif %}{{ provider.login_label }}
        {% endif %}
      </a>
    {% endif %}
  {% endfor %}
</div>
{% endif %}
