"""locked_structure

Revision ID: 0264
Revises: 0263
Create Date: 2025-02-05 13:16:17.623883

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0264'
down_revision = '0263'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('projects', sa.Column('locked_structure', sa.Boolean(), nullable=False, server_default="false"))


def downgrade():
    op.drop_column('projects', 'locked_structure')