"""delete_no_perm_role

Revision ID: 0275
Revises: 0274
Create Date: 2025-08-26 11:55:09.675251

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0275'
down_revision = '0274'
branch_labels = None
depends_on = None


def upgrade():
    op.execute("""
               DELETE FROM project_members WHERE role_id is null
            """)


def downgrade():
    pass
