"""group_always_show_desc

Revision: 0095
Revision ID: 19a97b706e5a
Revises: 31367f4af05e
Create Date: 2017-06-18 17:19:29.809802

"""

# revision identifiers, used by Alembic.
revision = '19a97b706e5a'
down_revision = '31367f4af05e'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.add_column('card_groups', sa.Column('always_show_description', sa.Boolean(), nullable=True))


def downgrade():
    op.drop_column('card_groups', 'always_show_description')
