"""added unindexed_value

Revision: 0005
Revision ID: 22bacef12338
Revises: 4ef62b5814cd
Create Date: 2015-06-05 11:15:40.074153

"""

# revision identifiers, used by Alembic.
revision = '22bacef12338'
down_revision = '4ef62b5814cd'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('card_attributes', sa.Column('unindexed_value', sa.Text(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('card_attributes', 'unindexed_value')
    ### end Alembic commands ###
