"""card_group_subs_user_id_index

Revision: 0214
Revision ID: 2e07de14ad8c
Revises: 8db3ad545942
Create Date: 2021-06-02 10:57:49.294543

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '2e07de14ad8c'
down_revision = '8db3ad545942'
branch_labels = None
depends_on = None


def upgrade():
    op.create_index(None, 'card_group_subscriptions', ['user_id'], unique=False)


def downgrade():
    pass
