"""add_cardlists_icon

Revision: 0013
Revision ID: 3ce3a91bc9eb
Revises: 48b6284b245e
Create Date: 2015-07-07 14:16:06.405804

"""

# revision identifiers, used by Alembic.
revision = '3ce3a91bc9eb'
down_revision = '48b6284b245e'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('card_lists', sa.Column('icon', sa.String(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('card_lists', 'icon')
    ### end Alembic commands ###
