"""added created_at

Revision: 0004
Revision ID: 4ef62b5814cd
Revises: 171c7a75ead7
Create Date: 2015-06-04 21:13:40.477672

"""

# revision identifiers, used by Alembic.
revision = '4ef62b5814cd'
down_revision = '171c7a75ead7'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('card_subscriptions', sa.Column('created_at', sa.DateTime(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('card_subscriptions', 'created_at')
    ### end Alembic commands ###
