"""add_github_scope

Revision: 0016
Revision ID: 302c2c3a9770
Revises: 1993ef6216c
Create Date: 2015-08-11 15:30:56.922506

"""

# revision identifiers, used by Alembic.
revision = '302c2c3a9770'
down_revision = '1993ef6216c'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('users', sa.Column('github_scope', sa.String(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('users', 'github_scope')
    ### end Alembic commands ###
