"""delete_null_values_from_card_attributes

Revision ID: 0249
Revises: 0248
Create Date: 2023-02-09 16:43:24.145429

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0249'
down_revision = '0248'
branch_labels = None
depends_on = None


def upgrade():
    op.execute("""
        DELETE FROM card_attributes
        WHERE value IS NULL AND unindexed_value IS NULL
    """)


def downgrade():
    pass
