"""email_not_unique

Revision: 0061
Revision ID: bfc8eb1f8c2
Revises: 7a809a8d04e
Create Date: 2016-08-05 13:58:25.895086

"""

# revision identifiers, used by Alembic.
revision = 'bfc8eb1f8c2'
down_revision = '7a809a8d04e'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.drop_constraint('users_email_key', 'users')
    op.create_index(op.f('ix_users_email'), 'users', ['email'], unique=False)


def downgrade():
    op.drop_index(op.f('ix_users_email'), table_name='users')
    op.create_unique_constraint("users_email_key", "users", ["email"])
