"""max_cards_limit

Revision: 0022
Revision ID: 10cf30e1e791
Revises: d4628b068b5
Create Date: 2015-09-06 14:27:52.473930

"""

# revision identifiers, used by Alembic.
revision = '10cf30e1e791'
down_revision = 'd4628b068b5'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('card_lists', sa.Column('max_cards_limit', sa.Integer(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('card_lists', 'max_cards_limit')
    ### end Alembic commands ###
