"""cardmodel_hide_children_attrs

Revision ID: 0282
Revises: 0281
Create Date: 2025-12-17 13:55:33.711351

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0282'
down_revision = '0281'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('card_models', sa.Column('hide_children_attributes', sa.Boolean()))
    op.execute("UPDATE card_models SET hide_children_attributes = false")


def downgrade():
    op.drop_column('card_models', 'hide_children_attributes')
