"""add_push_id

Revision: 0015
Revision ID: 1993ef6216c
Revises: 5a9e03d271b2
Create Date: 2015-07-09 18:00:41.774919

"""

# revision identifiers, used by Alembic.
revision = '1993ef6216c'
down_revision = '5a9e03d271b2'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('cards', sa.Column('push_id', sa.String(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('cards', 'push_id')
    ### end Alembic commands ###
