"""google_integration

Revision: 0127
Revision ID: 4e8938a1c66
Revises: 431110172682
Create Date: 2018-04-24 01:08:39.007577

"""

# revision identifiers, used by Alembic.
revision = '4e8938a1c66'
down_revision = '431110172682'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.add_column('users', sa.Column('google_token', sa.String(), nullable=True))
    op.add_column('users', sa.Column('google_refresh_token', sa.String(), nullable=True))
    op.add_column('users', sa.Column('google_id', sa.String(), nullable=True))
    op.add_column('users', sa.Column('google_name', sa.String(), nullable=True))
    op.add_column('users', sa.Column('google_email', sa.String(), nullable=True))
    op.create_index(op.f('ix_users_google_id'), 'users', ['google_id'], unique=False)


def downgrade():
    op.drop_column('users', 'google_token')
    op.drop_column('users', 'google_refresh_token')
    op.drop_column('users', 'google_id')
    op.drop_column('users', 'google_name')
    op.drop_column('users', 'google_email')
