"""add_share_object_options

Revision ID: 0252
Revises: 0251
Create Date: 2023-05-11 16:46:03.926683

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0252'
down_revision = '0251'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('share_objects', sa.Column('options', postgresql.JSONB()))


def downgrade():
    op.delete_column('share_objects', 'options')
