{% extends "users/layout.html" %}
{% block users_content %}
<form method="post" action="{{url_for('users.send_email_validation_email')}}" class="email-validation-form">
  <h2>{{ _("Verification link sent!") }}</h2>
  <img src="{{url_for_static('assets/send-invite.png')}}">
  <p>
    {{ _("We emailed a confirmation link to {email}<br>Check your email for a link to sign in.").format(email=email)|safe }}
  </p>
  <input type="hidden" name="email" value="{{email}}">
  <button type="submit" class="btn btn-default"><i class="fa fa-refresh"></i> {{_('Send again')}}</button>
</form>
{% endblock %}
