"""user_sub_required

Revision: 0043
Revision ID: 459ea8446830
Revises: da5397402d5
Create Date: 2015-12-16 07:56:15.797150

"""

# revision identifiers, used by Alembic.
revision = '459ea8446830'
down_revision = 'da5397402d5'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.add_column('users', sa.Column('subscription_required', sa.Boolean(), nullable=True))
    op.execute("UPDATE users SET subscription_required = true")


def downgrade():
    op.drop_column('users', 'subscription_required')
