"""card_started_at

Revision: 0086
Revision ID: 37726611a9ea
Revises: 2d68c5dd350e
Create Date: 2017-03-03 11:25:26.783510

"""

# revision identifiers, used by Alembic.
revision = '37726611a9ea'
down_revision = '2d68c5dd350e'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.add_column('cards', sa.Column('started_at', sa.DateTime(), nullable=True))


def downgrade():
    op.drop_column('cards', 'started_at')
