"""system_message

Revision: 0078
Revision ID: 4e9a229614fb
Revises: f6be47c2049
Create Date: 2016-12-06 20:28:55.915370

"""

# revision identifiers, used by Alembic.
revision = '4e9a229614fb'
down_revision = 'f6be47c2049'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.add_column('users', sa.Column('system_message', sa.Text(), nullable=True))


def downgrade():
    op.drop_column('users', 'system_message')
