"""disallow_card_creation_in_list

Revision: 0025
Revision ID: 568bf972b726
Revises: 188181cb15ef
Create Date: 2015-09-15 12:39:18.389728

"""

# revision identifiers, used by Alembic.
revision = '568bf972b726'
down_revision = '188181cb15ef'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

def upgrade():
    op.add_column('card_lists', sa.Column('disallow_direct_card_creation', sa.Boolean(), nullable=True))
    op.execute('UPDATE card_lists SET disallow_direct_card_creation = false')


def downgrade():
    op.drop_column('card_lists', 'disallow_direct_card_creation')