"""user_onboarded

Revision: 0065
Revision ID: 2daf3bc83d75
Revises: 24191069ca2a
Create Date: 2016-07-15 12:03:47.279709

"""

# revision identifiers, used by Alembic.
revision = '2daf3bc83d75'
down_revision = '24191069ca2a'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.add_column('users', sa.Column('onboarded', sa.Boolean(), nullable=True))
    op.execute("UPDATE users SET onboarded = true")


def downgrade():
    op.drop_column('users', 'onboarded')
