"""disable_ai_assistant

Revision ID: 0276
Revises: 0275
Create Date: 2025-09-05

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0276'
down_revision = '0275'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('organizations', sa.Column('ai_assistant_enabled', sa.Boolean(), nullable=False, server_default="false"))


def downgrade():
    op.drop_column('organizations', 'ai_assistant_enabled')
