"""template_icon_and_oneliner

Revision: 0101
Revision ID: 38487891c2c0
Revises: 3b0d34ece0d5
Create Date: 2017-07-13 18:59:27.544395

"""

# revision identifiers, used by Alembic.
revision = '38487891c2c0'
down_revision = '3b0d34ece0d5'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa

def upgrade():
    op.add_column('projects', sa.Column('icon', sa.String(), nullable=True))
    op.add_column('projects', sa.Column('oneliner', sa.Text(), nullable=True))

def downgrade():
    op.drop_column('projects', 'oneliner')
    op.drop_column('projects', 'icon')