"""user_license_through_org

Revision ID: 0283
Revises: 0282
Create Date: 2025-12-17 13:55:33.711351

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0283'
down_revision = '0282'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('users', sa.Column('licensed_through_org', sa.Boolean()))
    op.execute("UPDATE users SET licensed_through_org = false")


def downgrade():
    pass
