"""billing_activation_date

Revision: 0242
Revision ID: 3769937df895
Revises: 6372d988531f
Create Date: 2022-07-20 16:46:29.658713

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '3769937df895'
down_revision = '6372d988531f'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('billing_accounts', sa.Column('activation_date', sa.DateTime(), nullable=True))


def downgrade():
    op.drop_column('billing_accounts', 'activation_date')
