{% extends "layout.html" %}
{% block body_tag %}<body class="message-page">{% endblock %}
{% block content %}
  <div id="message-page-block">
    <img src="{{url_for_static('assets/logo-black.png')}}" alt="Kantree">
    <div class="message-content">{% block msg_content %}{% endblock %}</div>
  </div>
{% endblock %}
