"""added is_admin

Revision: 0007
Revision ID: 4ce0659a41fd
Revises: 43064fa5bc36
Create Date: 2015-06-10 19:35:59.527805

"""

# revision identifiers, used by Alembic.
revision = '4ce0659a41fd'
down_revision = '43064fa5bc36'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('users', sa.Column('is_admin', sa.Boolean(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('users', 'is_admin')
    ### end Alembic commands ###
