"""add_behavior_error

Revision: 0017
Revision ID: 26dc21c88e6
Revises: 302c2c3a9770
Create Date: 2015-08-12 15:11:48.168608

"""

# revision identifiers, used by Alembic.
revision = '26dc21c88e6'
down_revision = '302c2c3a9770'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('card_behaviors', sa.Column('error', sa.String(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('card_behaviors', 'error')
    ### end Alembic commands ###
