"""Reset groups cache

Revision: 0103
Revision ID: 575b3f3d895a
Revises: 14a5ced5c36c
Create Date: 2017-09-21 16:13:18.241319

"""

# revision identifiers, used by Alembic.
revision = '575b3f3d895a'
down_revision = '14a5ced5c36c'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

def upgrade():
    op.execute('UPDATE card_groups SET cache_id = uuid_generate_v4()')


def downgrade():
    op.execute('UPDATE card_groups SET cache_id = uuid_generate_v4()')
