"""view_include_descendants

Revision: 0125
Revision ID: 2387660ed43b
Revises: 76df933e43b
Create Date: 2018-04-16 18:13:46.993383

"""

# revision identifiers, used by Alembic.
revision = '2387660ed43b'
down_revision = '76df933e43b'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.add_column('views', sa.Column('include_descendants', sa.Boolean(), nullable=True))
    op.execute("UPDATE views SET include_descendants = false")


def downgrade():
    op.drop_column('views', 'include_descendants')
