{% extends "users/layout.html" %}
{% block users_content %}
  <{bs_form form=form action=url_for_same() class_="unsubscribe-form" }>
    <h2>{{title}}</h2>
    {% if not unsubscribed %}
    <div class="buttons">
      <{ bs_btn _("Unsubscribe") name="allow" type="submit" style="primary" size="lg" }/>
    </div>
    {% endif %}
  </{}>
{% endblock %}
