"""update_views_filter_due_week

Revision: 0139
Revision ID: 537f032a290d
Revises: 4e52740ad490
Create Date: 2018-07-26 16:07:29.309229

"""

# revision identifiers, used by Alembic.
revision = '537f032a290d'
down_revision = '4e52740ad490'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.execute("""
        UPDATE views SET filter = 'date?(week)' WHERE filter = 'due:week'
    """)


def downgrade():
    pass
