"""lock_view_edition

Revision ID: 0270
Revises: 0269
Create Date: 2025-02-07 09:11:53.319423

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0270'
down_revision = '0269'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('views', sa.Column('locked', sa.Boolean(), nullable=False, server_default="false"))


def downgrade():
    op.drop_column('views', 'locked')
