"""add_cardlists_desc

Revision: 0012
Revision ID: 48b6284b245e
Revises: 37d254b2a1bc
Create Date: 2015-07-07 09:55:31.583624

"""

# revision identifiers, used by Alembic.
revision = '48b6284b245e'
down_revision = '37d254b2a1bc'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('card_lists', sa.Column('description', sa.Text(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('card_lists', 'description')
    ### end Alembic commands ###
