"""google_token_expiry

Revision: 0128
Revision ID: 26834f77e639
Revises: 4e8938a1c66
Create Date: 2018-04-28 15:49:37.396271

"""

# revision identifiers, used by Alembic.
revision = '26834f77e639'
down_revision = '4e8938a1c66'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.add_column('users', sa.Column('google_token_expiry', sa.DateTime(), nullable=True))


def downgrade():
    op.drop_column('users', 'google_token_expiry')
