"""share_objects_unique_index

Revision: 0179
Revision ID: 1b68b8d9f3d6
Revises: 3c5285bbbb66
Create Date: 2020-04-17 10:32:26.948538

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '1b68b8d9f3d6'
down_revision = '3c5285bbbb66'
branch_labels = None
depends_on = None


def upgrade():
    op.drop_index(op.f('ix_share_objects_object_type_object_id'))
    op.create_index(op.f('ix_share_objects_object_type_object_id'), 'share_objects', ['object_type', 'object_id'], unique=True)


def downgrade():
    pass
