{% extends "app_message_layout.html" %}

{% block msg_content %}
<h1>Page not found!</h1>
<p>
  The requested page was not found in Kantree.
</p>
<p>
  <a href="/" target="_self" class="btn btn-primary">Go back to start page</a>
</p>
{% endblock %}
