"""user_auto_disable

Revision: 0157
Revision ID: 3068f1397e95
Revises: 3dd85740e8ac
Create Date: 2019-01-30 23:21:08.256457

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '3068f1397e95'
down_revision = '3dd85740e8ac'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('users', sa.Column('is_auto_disabled', sa.Boolean(), nullable=True))
    op.execute("""UPDATE users SET is_auto_disabled = false""")


def downgrade():
    op.drop_column('users', 'is_auto_disabled')
