"""org_color

Revision: 0212
Revision ID: 44a1660b8ce7
Revises: f9c853eb5e2c
Create Date: 2021-05-28 18:21:35.012925

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '44a1660b8ce7'
down_revision = 'f9c853eb5e2c'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('organizations', sa.Column('color', sa.String(), nullable=True))


def downgrade():
    op.drop_column('organizations', 'color')
