{% extends "users/layout.html" %}
{% block users_content %}
  <p>
    {{_("The following errors occured while trying to identify you via SAML:")}}
  </p>
  <ul>
    {% for error in errors %}
      <li>{{error}}</li>
    {% endfor %}
  </ul>
{% endblock %}
