{% if app.config['GOOGLE_ANALYTICS_ID'] %}
<script>
  (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
  (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
  m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
  })(window,document,'script','//www.google-analytics.com/analytics.js','ga');
  ga('create', '{{ app.config['GOOGLE_ANALYTICS_ID'] }}', 'auto');
  ga('send', 'pageview');
</script>
{% endif %}
{% if app.config['PLAUSIBLE_URL'] %}
<script async defer data-domain="{{app.config['SERVER_NAME']}}" src="{{app.config['PLAUSIBLE_URL']}}"></script>
<script>window.plausible = window.plausible || function() { (window.plausible.q = window.plausible.q || []).push(arguments) }</script>
{% endif %}
