"""added cache_id

Revision: 0006
Revision ID: 43064fa5bc36
Revises: 22bacef12338
Create Date: 2015-06-10 13:53:29.129453

"""

# revision identifiers, used by Alembic.
revision = '43064fa5bc36'
down_revision = '22bacef12338'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.add_column('organizations', sa.Column('cache_id', sa.String(), nullable=True))


def downgrade():
    op.drop_column('organizations', 'cache_id')
