{% extends "users/layout.html" %}
{% block users_content %}
  <{bs_form form=form action=url_for_same() class_="oauth-authorize-form" }>
    <h2>{{_("Allow <em>%(app)s</em> to access your account", app=grant.client.client_name)|safe}}</h2>
    {{grant.client.description|markdown|safe}}
    {% if scopes %}
    <h3>{{_("Requested permissions")}}:</h3>
    <ul class="list-unstyled">
      {% for scope in scopes %}<li>{{scope}}</li>{% endfor %}
    </ul>
    {% endif %}
    <div class="buttons">
      <{ bs_btn _("Allow") name="allow" type="submit" style="primary" size="lg" }/>
      <{ bs_btn _("Deny") name="deny" type="submit" style="default" size="lg" }/>
    </div>
  </{}>
{% endblock %}
