"""team_icon

Revision: 0209
Revision ID: f8fc6ca825a2
Revises: 41d379ba09af
Create Date: 2021-05-05 16:06:07.183238

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = 'f8fc6ca825a2'
down_revision = '41d379ba09af'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('teams', sa.Column('icon', sa.String(), nullable=True))


def downgrade():
    op.drop_column('teams', 'icon')
