"""org_featured_url

Revision: 0220
Revision ID: 1a49f15e6ab4
Revises: 233b7875868c
Create Date: 2021-09-09 17:07:42.079878

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '1a49f15e6ab4'
down_revision = '233b7875868c'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('organization_featured_items', sa.Column('url', sa.Text(), nullable=True))
    op.add_column('organization_featured_items', sa.Column('title', sa.Text(), nullable=True))
    op.add_column('organization_featured_items', sa.Column('favicon', sa.Text(), nullable=True))


def downgrade():
    op.drop_column('organization_featured_items', 'url')
    op.drop_column('organization_featured_items', 'title')
    op.drop_column('organization_featured_items', 'favicon')
