"""user_display_name

Revision: 0060
Revision ID: 7a809a8d04e
Revises: 4cd3011ada05
Create Date: 2016-06-26 22:31:17.157882

"""

# revision identifiers, used by Alembic.
revision = '7a809a8d04e'
down_revision = '4cd3011ada05'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.add_column('users', sa.Column('display_name', sa.String(), nullable=True))


def downgrade():
    op.drop_column('users', 'display_name')
