"""integration_system_app

Revision: 0236
Revision ID: 5f92d1bc0cfa
Revises: 8abfd8e00867
Create Date: 2022-02-15 15:38:32.262715

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '5f92d1bc0cfa'
down_revision = '8abfd8e00867'
branch_labels = None
depends_on = None


def upgrade():
    op.execute("UPDATE projects SET system_apps = array_append(system_apps, 'integrations')")


def downgrade():
    pass
