"""added_cards_mongo_id_index

Revision: 0010
Revision ID: 5a7dc5f0f913
Revises: 3a5f18e53496
Create Date: 2015-06-22 09:18:44.239036

"""

# revision identifiers, used by Alembic.
revision = '5a7dc5f0f913'
down_revision = '3a5f18e53496'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.create_index(op.f('ix_cards_mongo_id'), 'cards', ['mongo_id'], unique=False)
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(op.f('ix_cards_mongo_id'), table_name='cards')
    ### end Alembic commands ###
