"""request_form_no_request

Revision: 0215
Revision ID: 3c258d81bd0c
Revises: 2e07de14ad8c
Create Date: 2021-06-03 17:47:50.252203

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '3c258d81bd0c'
down_revision = '2e07de14ad8c'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('request_forms', sa.Column('request_page', sa.Boolean(), nullable=True))
    op.add_column('request_forms', sa.Column('email_required', sa.Boolean(), nullable=True))
    op.execute("UPDATE request_forms SET request_page = true, email_required = true")


def downgrade():
    op.drop_column('request_forms', 'request_page')
    op.drop_column('request_forms', 'email_required')
