"""signup_utmz

Revision: 0116
Revision ID: 525735b60e4d
Revises: 28ef45c94dfd
Create Date: 2018-03-13 15:00:57.887617

"""

# revision identifiers, used by Alembic.
revision = '525735b60e4d'
down_revision = '28ef45c94dfd'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


def upgrade():
    op.add_column('users', sa.Column('signup_utma', postgresql.JSONB(), nullable=True))
    op.add_column('users', sa.Column('signup_utmz', postgresql.JSONB(), nullable=True))
    op.create_index(op.f('ix_users_signup_utmz'), 'users', ['signup_utmz'], unique=False)


def downgrade():
    op.drop_column('users', 'signup_utmz')
    op.drop_column('users', 'signup_utma')
