"""only_show_own_model_attributes

Revision ID: 0256
Revises: 0255
Create Date: 2024-03-29 20:35:37.091447

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0256'
down_revision = '0255'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('card_models', sa.Column('only_show_own_attributes', sa.Boolean()))
    op.execute("UPDATE card_models SET only_show_own_attributes = false")


def downgrade():
    op.drop_column('card_models', 'only_show_own_attributes')
