{% extends "users/layout.html" %}
{% block users_title %}{{ _("You are logged out") }}{% endblock %}
{% block users_content %}
<p>{{_("You have have been successfully logged out")}}</p>
<p>
  <a href="{{url_for('users.login')}}" class="btn btn-cta">Login again</a>
  {% if 'kantree_saml' in app.extensions %}
  <a href="{{url_for('users.login')}}?no_redirect=1" class="btn btn-default">Login using Kantree credentials</a>
  {% endif %}
</p>
{% endblock %}
