"""views_lane_grouped_by_name

Revision: 0176
Revision ID: 4fc19fa2e6da
Revises: 4d90b902c3e0
Create Date: 2020-01-27 18:18:33.800145

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '4fc19fa2e6da'
down_revision = '4d90b902c3e0'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('views', sa.Column('lane_group_by_name', sa.String(), nullable=True))


def downgrade():
    op.drop_column('views', 'lane_group_by_name')
