"""update_board_tpl

Revision: 0014
Revision ID: 5a9e03d271b2
Revises: 3ce3a91bc9eb
Create Date: 2015-07-07 14:35:46.443980

"""

# revision identifiers, used by Alembic.
revision = '5a9e03d271b2'
down_revision = '3ce3a91bc9eb'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('board_template_lists', sa.Column('description', sa.Text(), nullable=True))
    op.add_column('board_template_lists', sa.Column('icon', sa.String(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('board_template_lists', 'icon')
    op.drop_column('board_template_lists', 'description')
    ### end Alembic commands ###
