"""project_gantt_config

Revision ID: 0279
Revises: 0278
Create Date: 2024-11-18 22:34:16.800414

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql
from sqlalchemy.ext.mutable import MutableDict


# revision identifiers, used by Alembic.
revision = '0279'
down_revision = '0278'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('projects', sa.Column('gantt_config', MutableDict.as_mutable(postgresql.JSONB), nullable=True))


def downgrade():
    op.drop_column('projects', 'gantt_config')
