"""form_unlisted

Revision: 0239
Revision ID: 3fa23c3f6c07
Revises: f9352a1f06eb
Create Date: 2022-03-15 15:51:03.480390

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '3fa23c3f6c07'
down_revision = 'f9352a1f06eb'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('request_forms', sa.Column('unlisted', sa.Boolean(), nullable=True))
    op.execute("UPDATE request_forms SET unlisted = false")


def downgrade():
    op.drop_column('request_forms', 'unlisted')
