"""ai_context

Revision ID: 0267
Revises: 0266
Create Date: 2025-06-17 13:16:17.623883

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0267'
down_revision = '0266'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('projects', sa.Column('ai_context', sa.String()))


def downgrade():
    op.drop_column('projects', 'ai_context')