"""delete_projects_without_top_card

Revision: 0134
Revision ID: 11fab9822bf6
Revises: 4cee323fc652
Create Date: 2018-06-12 15:45:37.410916

"""

# revision identifiers, used by Alembic.
revision = '11fab9822bf6'
down_revision = '4cee323fc652'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.execute('DELETE FROM projects WHERE top_level_card_id IS NULL')


def downgrade():
    pass
