"""ai_provider

Revision ID: 0272
Revises: 0271
Create Date: 2025-06-17 13:16:17.623883

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0272'
down_revision = '0271'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('organizations', sa.Column('ai_provider', sa.Text()))
    op.add_column('organizations', sa.Column('ai_context', sa.Text()))

def downgrade():
    op.drop_column('organizations', 'ai_provider')
    op.drop_column('organizations', 'ai_context')