"""signup_referrer

Revision: 0202
Revision ID: 47e876a62c34
Revises: d8b702a1eee2
Create Date: 2021-01-15 16:18:48.661982

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '47e876a62c34'
down_revision = 'd8b702a1eee2'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('users', sa.Column('signup_referrer', sa.String(), nullable=True))


def downgrade():
    op.drop_column('users', 'signup_referrer')
