"""oauth_auto_app

Revision ID: 0245
Revises: 3dc5ebfeecea
Create Date: 2022-06-03 10:33:29.708025

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0245'
down_revision = '3dc5ebfeecea'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('oauth_apps', sa.Column('auto_app_name', sa.String()))


def downgrade():
    op.drop_column('oauth_apps', 'auto_app_name')
