"""ai_settings

Revision ID: 0266
Revises: 0265
Create Date: 2025-06-17 13:16:17.623883

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0266'
down_revision = '0265'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('organizations', sa.Column('ai_enabled', sa.Boolean()))
    op.add_column('organizations', sa.Column('ai_base_url', sa.String()))
    op.add_column('organizations', sa.Column('ai_api_key', sa.String()))
    op.add_column('organizations', sa.Column('ai_model', sa.String()))


def downgrade():
    op.drop_column('organizations', 'ai_enabled')
    op.drop_column('organizations', 'ai_base_url')
    op.drop_column('organizations', 'ai_api_key')
    op.drop_column('organizations', 'ai_model')