"""background_color_and_icon_in_rules

Revision ID: 0271
Revises: 0270
Create Date: 2025-02-28 11:02:20.935912

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0271'
down_revision = '0270'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('automation_rules', sa.Column('icon', sa.String(), nullable=True))
    op.add_column('automation_rules', sa.Column('background_color', sa.String(), nullable=True))


def downgrade():
    op.drop_column('automation_rules', 'icon')
    op.drop_column('automation_rules', 'background_color')
