"""allow_anon_inbound_emails

Revision: 0142
Revision ID: 52f62ba42efb
Revises: 1d830ee99d4c
Create Date: 2018-10-04 10:27:43.017344

"""

# revision identifiers, used by Alembic.
revision = '52f62ba42efb'
down_revision = '1d830ee99d4c'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.add_column('projects', sa.Column('allow_anon_inbound_emails', sa.Boolean(), nullable=True))
    op.execute('UPDATE projects SET allow_anon_inbound_emails = false')


def downgrade():
    op.drop_column('projects', 'allow_anon_inbound_emails')
