"""views_grouped_by_name

Revision: 0158
Revision ID: 495c4d953e01
Revises: 3068f1397e95
Create Date: 2019-02-10 18:07:52.756131

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '495c4d953e01'
down_revision = '3068f1397e95'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('views', sa.Column('group_by_name', sa.String(), nullable=True))


def downgrade():
    op.drop_column('views', 'group_by_name')
