"""import_status

Revision: 0058
Revision ID: 3bc28e6d9f90
Revises: 36a48ba6355f
Create Date: 2016-05-18 20:27:57.283740

"""

# revision identifiers, used by Alembic.
revision = '3bc28e6d9f90'
down_revision = '36a48ba6355f'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.add_column('cards', sa.Column('import_status', sa.String(), nullable=True))


def downgrade():
    op.drop_column('cards', 'import_status')
