<!DOCTYPE html>
<html>
<head lang="{{g.current_locale}}">
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <base href="/">
  <meta name="robots" content="noindex,nofollow">
  <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no">
  <link rel="mask-icon" href="{{ url_for_static('assets/logo.svg') }}" color="#63CF80">
  <link rel="icon" type="img/png" href="{{ url_for_static('assets/favicon.png') }}">

  <title>{{app.config['TITLE']}}</title>

  {% block head %}
  <{ legacy_asset_tags [] CSS_ASSETS }/>
  {% endblock %}
</head>

{% block body %}
{% block body_tag %}<body>{% endblock %}
  <div id="app-container">
    {% block content %}{% endblock %}
  </div>
  {% block footer %}{% endblock %}
</body>
{% endblock %}
</html>
