{% extends "app_message_layout.html" %}

{% block msg_content %}
<h1>An error occured!</h1>
<p>
  Kantree experienced an error from which it cannot recover.
</p>
{% if app.config['SUPPORT_EMAIL'] %}
<p>
    If this keeps happening, shoot us a mail at {{app.config['SUPPORT_EMAIL']}}.
</p>
{% endif %}
{% endblock %}
