"""automation_is_erroring

Revision ID: 0248
Revises: 0247
Create Date: 2022-11-16 10:22:56.196290

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0248'
down_revision = '0247'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('automation_rules', sa.Column('is_erroring', sa.Boolean()))


def downgrade():
    op.drop_column('automation_rules', 'is_erroring')
