"""more_indexes

Revision: 0049
Revision ID: 1336f79b826c
Revises: 3e7436bcd512
Create Date: 2016-02-25 18:19:30.319504

"""

# revision identifiers, used by Alembic.
revision = '1336f79b826c'
down_revision = '3e7436bcd512'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.create_index(op.f('ix_card_groups_cards_group_id_position'),
        'card_groups_cards', ['group_id', 'position'], unique=False)
    op.create_index(op.f('ix_cards_link_to_id'),
        'cards', ['link_to_id'], unique=False)


def downgrade():
    op.drop_index(op.f('ix_cards_link_to_id'), table_name='cards')
    op.drop_index(op.f('ix_card_groups_cards_group_id_position'), table_name='card_groups_cards')
