"""org_can_self_export

Revision: 0137
Revision ID: 17e5c6904ce1
Revises: 53e5e98f0381
Create Date: 2018-07-10 13:35:43.284297

"""

# revision identifiers, used by Alembic.
revision = '17e5c6904ce1'
down_revision = '53e5e98f0381'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.add_column('organizations', sa.Column('can_self_export', sa.Boolean(), nullable=True))
    op.execute("UPDATE organizations SET can_self_export = false")


def downgrade():
    op.drop_column('organizations', 'can_self_export')
