"""org_feature_flags

Revision ID: 0257
Revises: 0256
Create Date: 2023-03-16 16:39:06.127824

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0257'
down_revision = '0256'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('organizations', sa.Column('feature_flags', postgresql.ARRAY(sa.Text)))


def downgrade():
    op.drop_column('organizations', 'feature_flags')
