"""reset_model_cache_id

Revision ID: 0273
Revises: 0272
Create Date: 2025-06-17 13:16:17.623883

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0273'
down_revision = '0272'
branch_labels = None
depends_on = None


def upgrade():
    op.execute("""
        UPDATE card_models SET cache_id = uuid_generate_v4()
    """)


def downgrade():
    pass
