"""forms_anonymous_email_field

Revision: 0180
Revision ID: 175395377f47
Revises: 1b68b8d9f3d6
Create Date: 2020-04-17 12:47:42.393240

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '175395377f47'
down_revision = '1b68b8d9f3d6'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('request_forms', sa.Column('anonymous_email_field_id', sa.Integer(), nullable=True))
    op.create_foreign_key(None, 'request_forms', 'request_form_fields', ['anonymous_email_field_id'], ['id'])


def downgrade():
    op.drop_column('request_forms', 'anonymous_email_field_id')
