"""view_filter_scopes

Revision: 0190
Revision ID: f6c9987ca2e6
Revises: 5bcdd81f9309
Create Date: 2020-08-14 19:02:27.445260

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = 'f6c9987ca2e6'
down_revision = '5bcdd81f9309'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('views', sa.Column('filter_scopes', postgresql.JSONB(), nullable=True))


def downgrade():
    op.drop_column('views', 'filter_scopes')
