"""added slug to organization

Revision: 0003
Revision ID: 171c7a75ead7
Revises: 8c4d6851928
Create Date: 2015-06-03 20:49:17.939576

"""

# revision identifiers, used by Alembic.
revision = '171c7a75ead7'
down_revision = '8c4d6851928'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('organizations', sa.Column('slug', sa.String(), nullable=True))
    op.create_unique_constraint(None, 'organizations', ['slug'])
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, 'organizations', type_='unique')
    op.drop_column('organizations', 'slug')
    ### end Alembic commands ###
