{% extends "app_message_layout.html" %}

{% block msg_content %}
{% if request.method == 'GET' %}
<form action="" method="post">
  <input type="hidden" name="__" value="">
</form>
<script>
  setTimeout(function() {
    document.querySelector('form').submit();
  }, 500);
</script>
{% elif error %}
<h1>{{_("An error has occured")}}</h1>
<p>{{error}}</p>
{% else %}
<h1>{{_("Automation has successfully ran!")}}</h1>
{% endif %}
{% endblock %}
