{% use_layout %}

{% block head %}

<script type="text/javascript">
  var KANTREE_VERSION = "{{ app.config['APP_VERSION'] }}";
  var KANTREE_CONFIG = {{ KANTREE_WEB_CONFIG|tojson|safe }};
  {% if app.debug %}var KANTREE_DEBUG = true;{% endif %}
</script>

<{ cache_service_worker }/>

<{ legacy_asset_tags JS_APP_ASSETS CSS_ASSETS }/>
{% if g.current_locale != 'en' %}
  {% legacy_assets "locale_%s_js" % g.current_locale %}
    <script type="text/javascript" src="{{ ASSET_URL }}"></script>
  {% endassets %}
{% endif %}
{% asset_tags %}
<script type="module">
  kantree.bootstrap();
</script>

{% endblock %}

{% block body %}
<body>
  <noscript>Please activate javascript</noscript>
  <div id="app-root"></div>
</body>
{% endblock %}
