"""remove_email_templates_owner_id

Revision: 0195
Revision ID: b1c116f20ed0
Revises: 7230cc1e84bc
Create Date: 2020-10-13 23:29:39.023057

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = 'b1c116f20ed0'
down_revision = '7230cc1e84bc'
branch_labels = None
depends_on = None


def upgrade():
    op.drop_column('email_templates', 'owner_id')


def downgrade():
    pass
