import "./legacy-vendors/gridstack.all.min.js"
import "moment/moment.js"
import "moment-timezone/builds/moment-timezone-with-data.js"
import "jquery/dist/jquery.js"
import "bootstrap/dist/js/bootstrap.js"
import "jquery-ui-dist/jquery-ui.js"
import "angular/angular.js"
import "./legacy-vendors/angular-backcompat.js"
import "angular-sanitize/angular-sanitize.js"
import "ui-select/dist/select.js"
import "angular-ui-bootstrap/dist/ui-bootstrap-tpls.js"
import "angular-hotkeys/build/hotkeys.js"
import "angular-bootstrap-lightbox/dist/angular-bootstrap-lightbox.js"
import "angular-country-picker/country-picker.min.js"
import "angular-widget-grid/angular-widget-grid.js"
import "ng-file-upload/dist/ng-file-upload.js"
import "sweetalert2/dist/sweetalert2.js"
import "marked/lib/marked.umd.js"
import "lunr/lunr.min.js"
import "bootstrap-toggle/js/bootstrap-toggle.js"
import "jstree/dist/jstree.js"
import "clipboard/dist/clipboard.js"
import "file-saver/dist/FileSaver.js"
import "handlebars/dist//handlebars.runtime.js"
import "js-sha256/src/sha256.js"
import "aes-js/index.js"
import "fullcalendar/dist/fullcalendar.js"
import "ng-fittext/src/ng-FitText.js"
import "@popperjs/core/dist/umd/popper.min.js"
import "tinycolor2/dist/tinycolor-min.js"
import "tippy.js/dist/tippy-bundle.umd.js"
import "simplebar/dist/simplebar.min.js"
import "jquery.scrollto/jquery.scrollTo.js"
import "chart.js/dist/chart.js"
import "chartjs-plugin-datalabels/dist/chartjs-plugin-datalabels.js"
import "chartjs-adapter-moment/dist/chartjs-adapter-moment.js"
import "videogular/dist/videogular/videogular.js"
import "compare-versions/index.js"
import "./legacy-vendors/forks/angular-bootstrap-modal-window.js"
import "./legacy-vendors/forks/angular-touch.js"
import "./legacy-vendors/forks/autosize.js"
import "./legacy-vendors/forks/canvas-toBlob.js"
import "./legacy-vendors/forks/removeClassRegex.js"
import "./legacy-vendors/forks/daterangepicker.js"
import "./legacy-vendors/forks/jquery-ui-sortable.js"
import "./legacy-vendors/forks/jquery-ui-touch-punch.js"
import "./legacy-vendors/forks/ng-sortable.js"
import "./legacy-vendors/forks/tether.js"
import "./legacy-vendors/forks/tether-custom-constraint-module.js"
import "./legacy-vendors/forks/drop.js"
import "./legacy-vendors/script.js"
// "frasco_push/socketio-client.js",
// "frasco_push/push-client.js",

import "angular-bootstrap-lightbox/dist/angular-bootstrap-lightbox.css"
import "angular-hotkeys/build/hotkeys.css"
import "angular-widget-grid/angular-widget-grid.css"
import "ui-select/dist/select.css"
import "sweetalert2/dist/sweetalert2.css"
import "bootstrap-toggle/css/bootstrap-toggle.css"
import "loaders.css/loaders.css"
import "bootstrap-daterangepicker/daterangepicker.css"
import "air-datepicker/air-datepicker.css"
import "fullcalendar/dist/fullcalendar.css"
import "gridstack/dist/gridstack.css"
import "simplebar/dist/simplebar.css"
import "tippy.js/dist/tippy.css"
import "passtrength/dist/css/passtrength.css"
import "videogular/dist/themes/default/videogular.css"
