"""group_type_auto_period

Revision: 0036
Revision ID: 52ccef8b0e0
Revises: 30849ae581ab
Create Date: 2015-11-26 00:17:34.406808

"""

# revision identifiers, used by Alembic.
revision = '52ccef8b0e0'
down_revision = '30849ae581ab'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

def upgrade():
    op.add_column('card_group_types', sa.Column('auto_assign_period', sa.String(), nullable=True))


def downgrade():
    op.drop_column('card_group_types', 'auto_assign_period')
