{% extends "users/layout.html" %}
{% block users_content %}
<form action="" method="post" id="send-reset-password-form" class="login-form">
  {{ form.hidden_tag() }}
  <h2>{{ _("Reset your password") }}</h2>
  <div class="form-group">
    <label for="identifier" class="form-label">{{_("Your email address")}}</label>
    {{ form.email(class_="form-control form-control-lg", placeholder="you@company.com") }}
  </div>
  <button type="submit" class="btn btn-primary btn-lg">{{_("Send email to reset password")}}</button>
</form>
{% endblock %}
