"""automation_rules_exposed

Revision ID: 0285
Revises: 0284
Create Date: 2026-02-13 12:58:57.932100

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '0285'
down_revision = '0284'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('automation_rules', sa.Column('exposed', sa.Boolean()))
    op.execute("UPDATE automation_rules SET exposed = false")


def downgrade():
    pass
