"""request_form_email_sender

Revision: 0168
Revision ID: 2212e3bc7f5f
Revises: 3cdc91fa1c35
Create Date: 2019-07-02 15:15:02.267714

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '2212e3bc7f5f'
down_revision = '3cdc91fa1c35'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('request_forms', sa.Column('email_sender', sa.String(), nullable=True))


def downgrade():
    op.drop_column('request_forms', 'email_sender')
